==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/component/impl/C_ISetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.interfaces.IfaceSet;
import io.ciera.tool.sql.architecture.interfaces.impl.IfaceSetImpl;
import io.ciera.tool.sql.ooaofooa.component.C_I;
import io.ciera.tool.sql.ooaofooa.component.C_ISet;
import io.ciera.tool.sql.ooaofooa.component.ExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceReferenceSet;
import io.ciera.tool.sql.ooaofooa.component.impl.ExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;

import java.util.Arrays;
import java.util.List;


public class C_ISetImpl extends InstanceSet<C_ISet,C_I> implements C_ISet {

    // attributes
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( C_I c_i : this ) c_i.setId( ref_Id );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( C_I c_i : this ) c_i.setName( m_Name );
    }
    @Override
    public void setPackage_IDdeprecated( UniqueId m_Package_IDdeprecated ) throws XtumlException {
        for ( C_I c_i : this ) c_i.setPackage_IDdeprecated( m_Package_IDdeprecated );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( C_I c_i : this ) c_i.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public ExecutablePropertySet R4003_is_defined_by_ExecutableProperty() throws XtumlException {
        ExecutablePropertySet executablepropertyset = new ExecutablePropertySetImpl();
        for ( C_I c_i : this ) executablepropertyset.addAll( c_i.R4003_is_defined_by_ExecutableProperty() );
        return executablepropertyset;
    }
    @Override
    public InterfaceReferenceSet R4012_is_formal_definition_InterfaceReference() throws XtumlException {
        InterfaceReferenceSet interfacereferenceset = new InterfaceReferenceSetImpl();
        for ( C_I c_i : this ) interfacereferenceset.addAll( c_i.R4012_is_formal_definition_InterfaceReference() );
        return interfacereferenceset;
    }
    @Override
    public IfaceSet R421_is_basis_for_Iface() throws XtumlException {
        IfaceSet ifaceset = new IfaceSetImpl();
        for ( C_I c_i : this ) ifaceset.add( c_i.R421_is_basis_for_Iface() );
        return ifaceset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( C_I c_i : this ) packageableelementset.add( c_i.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public C_I nullElement() {
        return C_IImpl.EMPTY_C_I;
    }

    @Override
    public C_ISet emptySet() {
      return new C_ISetImpl();
    }

    @Override
    public C_ISet value() {
        return this;
    }

    @Override
    public List<C_I> elements() {
        C_I[] elements = toArray(new C_I[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/component/impl/C_ISetImpl.java <==
package io.ciera.tool.sql.ooaofooa.component.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.interfaces.IfaceSet;
import io.ciera.tool.sql.architecture.interfaces.impl.IfaceSetImpl;
import io.ciera.tool.sql.ooaofooa.component.C_I;
import io.ciera.tool.sql.ooaofooa.component.C_ISet;
import io.ciera.tool.sql.ooaofooa.component.ExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceReferenceSet;
import io.ciera.tool.sql.ooaofooa.component.impl.ExecutablePropertySetImpl;
import io.ciera.tool.sql.ooaofooa.component.impl.InterfaceReferenceSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class C_ISetImpl extends InstanceSet<C_ISet,C_I> implements C_ISet {

    public C_ISetImpl() {
    }

    public C_ISetImpl(Comparator<? super C_I> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( C_I c_i : this ) c_i.setName( m_Name );
    }
    @Override
    public void setId( UniqueId ref_Id ) throws XtumlException {
        for ( C_I c_i : this ) c_i.setId( ref_Id );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( C_I c_i : this ) c_i.setDescrip( m_Descrip );
    }
    @Override
    public void setPackage_IDdeprecated( UniqueId m_Package_IDdeprecated ) throws XtumlException {
        for ( C_I c_i : this ) c_i.setPackage_IDdeprecated( m_Package_IDdeprecated );
    }


    // selections
    @Override
    public ExecutablePropertySet R4003_is_defined_by_ExecutableProperty() throws XtumlException {
        ExecutablePropertySet executablepropertyset = new ExecutablePropertySetImpl();
        for ( C_I c_i : this ) executablepropertyset.addAll( c_i.R4003_is_defined_by_ExecutableProperty() );
        return executablepropertyset;
    }
    @Override
    public InterfaceReferenceSet R4012_is_formal_definition_InterfaceReference() throws XtumlException {
        InterfaceReferenceSet interfacereferenceset = new InterfaceReferenceSetImpl();
        for ( C_I c_i : this ) interfacereferenceset.addAll( c_i.R4012_is_formal_definition_InterfaceReference() );
        return interfacereferenceset;
    }
    @Override
    public IfaceSet R421_is_basis_for_Iface() throws XtumlException {
        IfaceSet ifaceset = new IfaceSetImpl();
        for ( C_I c_i : this ) ifaceset.add( c_i.R421_is_basis_for_Iface() );
        return ifaceset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( C_I c_i : this ) packageableelementset.add( c_i.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }


    @Override
    public C_I nullElement() {
        return C_IImpl.EMPTY_C_I;
    }

    @Override
    public C_ISet emptySet() {
      return new C_ISetImpl();
    }

    @Override
    public C_ISet emptySet(Comparator<? super C_I> comp) {
      return new C_ISetImpl(comp);
    }

    @Override
    public C_ISet value() {
        return this;
    }

    @Override
    public List<C_I> elements() {
        C_I[] elements = toArray(new C_I[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
